package cn.com.ty.lift.business.contract.controller;

import cn.com.ty.lift.business.contract.dao.entity.PaymentHistory;
import cn.com.ty.lift.business.contract.dao.entity.model.request.ContractsHistoryRequest;
import cn.com.ty.lift.business.contract.dao.entity.model.request.PaymentDetailRequest;
import cn.com.ty.lift.business.contract.dao.entity.model.request.PaymentModifyRequest;
import cn.com.ty.lift.business.contract.dao.entity.model.request.PaymentRequest;
import cn.com.ty.lift.business.contract.dao.entity.model.response.PaymentDetailResponse;
import cn.com.ty.lift.business.contract.dao.entity.model.response.PaymentResponse;
import cn.com.ty.lift.business.contract.service.PaymentHistoryService;
import cn.com.ty.lift.business.contract.service.PaymentService;
import cn.com.ty.lift.business.framework.util.MessageUtils;
import cn.com.xwy.boot.web.dto.RestResponse;
import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.Valid;

/**
 * @author bieao
 * @date 2020/2/20
 * @description 付款管理控制层
 */
@RestController
@RequestMapping("payment")
public class PaymentController {

    @Resource
    private PaymentService paymentService;

    @Resource
    private PaymentHistoryService paymentHistoryService;

    /**
     * @param request 收款列表查询条件
     * @return RestResponse 付款分页列表结果
     * @description 查询收款列表
     * @date 2020/2/20 3:10 下午
     */
    @PostMapping("list")
    public RestResponse list(@Valid @RequestBody PaymentRequest request) {
        IPage<PaymentResponse> page = paymentService.list(request);
        if (CollUtil.isEmpty(page.getRecords())) {
            return RestResponse.success();
        }
        return RestResponse.success(page, MessageUtils.get("msg.query.success"));
    }

    /**
     * @param request 收款详情查询条件
     * @return RestResponse 付款详情
     * @description 查询收款详情
     * @date 2020/2/24 10:47 上午
     */
    @PostMapping("detail")
    public RestResponse detail(@Valid @RequestBody PaymentDetailRequest request){
       PaymentDetailResponse response = paymentService.detail(request);
       if (ObjectUtil.isEmpty(response)){
           return RestResponse.success();
       }
       return RestResponse.success(response, MessageUtils.get("msg.query.detail.success"));
    }

    /**
     * @param request 收款列表
     * @return 1.成功, 0.失败, 消息描述
     * @description 批量修改收款信息
     * @date 2020/2/24 10:47 上午
     */
    @PostMapping("batch/modify")
    public RestResponse batchModify(@Valid @RequestBody PaymentModifyRequest request) {
        boolean result = paymentService.modifyBatchById(request.getPaymentList());
        if (result) {
            return RestResponse.success(null, MessageUtils.get("msg.modify.success"));
        } else {
            return RestResponse.fail(MessageUtils.get("msg.modify.fail"));
        }
    }

    /**
     * @param request 操作记录查询条件
     * @return RestResponse 付款操作记录分页列表结果
     * @description 查询付款操作记录列表
     * @date 2020/2/26 5:13 下午
     */
    @PostMapping("history/list")
    public RestResponse historyList(@Valid @RequestBody ContractsHistoryRequest request) {
        IPage<PaymentHistory> page = paymentHistoryService.list(request);
        if (CollUtil.isEmpty(page.getRecords())) {
            return RestResponse.success();
        }
        return RestResponse.success(page, MessageUtils.get("msg.query.success"));
    }
}
