package cn.com.ty.lift.system.config;

import cn.com.ty.lift.common.verify.Ver;
import cn.com.ty.lift.common.verify.Verification;
import cn.com.ty.lift.common.verify.Verifier;
import org.aopalliance.intercept.MethodInterceptor;
import org.aopalliance.intercept.MethodInvocation;

import java.lang.reflect.Method;
import java.lang.reflect.Parameter;

/**
 * the {@link MethodInterceptor} to verify the parameters
 *
 * @author wcz
 * @since 2020/2/25
 */
public class VerifyMethodInterceptor implements MethodInterceptor {
    @Override
    public Object invoke(MethodInvocation invocation) throws Throwable {
        //get the method
        Method method = invocation.getMethod();
        //check whether the method is present with verifier annotation.
        if (!method.isAnnotationPresent(Verifier.class)) {
            return invocation.proceed();
        }

        Object[] arguments = invocation.getArguments();
        //just return if there is not any argument.
        if (arguments.length == 0) {
            return invocation.proceed();
        }
        Object object = null;
        //by default, verify the first arg present with Ver
        Parameter[] parameters = method.getParameters();
        for (int i = 0; i < parameters.length; i++) {
            if(parameters[i].isAnnotationPresent(Ver.class)){
                object = arguments[i];
                break;
            }
        }
        if (null == object) {
            return invocation.proceed();
        }
        //get the verifier
        Verifier verifier = method.getDeclaredAnnotation(Verifier.class);
        Verification.getInstance().action(object, verifier.fields());
        return invocation.proceed();
    }
}
